==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/User/Directory/Ldap/Container/ContainersCollection.php <==
<?php
namespace Claromentis\Core\User\Directory\Ldap\Container;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] ?: array()) + array("_f73dab606630b388" . "645c4f7d3fbb13bb" => base64_decode("YXJyYXl" . "fbWVyZ2" . "U="));




class ContainersCollection implements UsersContainerInterface
{
    protected $containers;
    public function __construct($_c215cd00a44d3b2a7f2b40b96f3aaa9f = [])
    {
        $this->containers = $_c215cd00a44d3b2a7f2b40b96f3aaa9f;
    }
    public function AddContainer(UsersContainerInterface $_5e4594441b0e531bfd6f0011e0327611)
    {
        $this->containers[] = $_5e4594441b0e531bfd6f0011e0327611;
    }
    public function GetMembers()
    {
        $_e4543e131c67c631b14751cc849d1310 = [];
        foreach ($this->containers as $_5e4594441b0e531bfd6f0011e0327611) {
            
            
            $_e4543e131c67c631b14751cc849d1310 = $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_f73dab606630b3" . "88645c4f7d3fbb1" . "3bb"]($_e4543e131c67c631b14751cc849d1310, $_5e4594441b0e531bfd6f0011e0327611->GetMembers());
        }
        
        
        return $_e4543e131c67c631b14751cc849d1310;
    }
    public function IsMember($_c031077013afa9973ad3516e1ad65118)
    {
        foreach ($this->containers as $_5e4594441b0e531bfd6f0011e0327611) {
            
            
            if ($_5e4594441b0e531bfd6f0011e0327611->IsMember($_c031077013afa9973ad3516e1ad65118)) {
                return true;
            }
        }
        return false;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/User/Directory/Ldap/Container/ContainersCollection.php <==
<?php
namespace Claromentis\Core\User\Directory\Ldap\Container;

$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array("_f73dab60663" . "0b388645c4f7" . "d3fbb13bb" => base64_decode("YXJyYXlfbW" . "VyZ2U="));




class ContainersCollection implements UsersContainerInterface
{
    protected $containers;
    public function __construct($_c215cd00a44d3b2a7f2b40b96f3aaa9f = [])
    {
        $this->containers = $_c215cd00a44d3b2a7f2b40b96f3aaa9f;
    }
    public function AddContainer(UsersContainerInterface $_5e4594441b0e531bfd6f0011e0327611)
    {
        $this->containers[] = $_5e4594441b0e531bfd6f0011e0327611;
    }
    public function GetMembers()
    {
        $_e4543e131c67c631b14751cc849d1310 = [];
        foreach ($this->containers as $_5e4594441b0e531bfd6f0011e0327611) {
            
            
            $_e4543e131c67c631b14751cc849d1310 = $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_f73dab60663" . "0b388645c4f7" . "d3fbb13bb"]($_e4543e131c67c631b14751cc849d1310, $_5e4594441b0e531bfd6f0011e0327611->GetMembers());
        }
        
        
        return $_e4543e131c67c631b14751cc849d1310;
    }
    public function IsMember($_c031077013afa9973ad3516e1ad65118)
    {
        foreach ($this->containers as $_5e4594441b0e531bfd6f0011e0327611) {
            
            
            if ($_5e4594441b0e531bfd6f0011e0327611->IsMember($_c031077013afa9973ad3516e1ad65118)) {
                return true;
            }
        }
        return false;
    }
}
